@@ -11,13 +11,19 @@ mod hashing;
 mod model;
 mod reporter;
 
+const ERROR_EXIT_CODE: i32 = 1;
+
 fn main() {
     pretty_env_logger::init();
     let arguments = cli::Arguments::from_args();
     debug!("The command line arguments provided are {:?}.", arguments);
 
     let raw_files = crate::directory_reader::get_files_in_current_directory();
-    let indexed_files = crate::model::indexed_file::to_indexed_files(raw_files);
+    let indexed_files = crate::model::indexed_file::to_indexed_files(
+        arguments.ignore_file_regex,
+        arguments.ignore_line_regex,
+        raw_files,
+    );
     let hashed_files = crate::model::hashed_file::to_hashed_files(&indexed_files);
     let duplicates = crate::duplicate_detection::get_all_duplicates(hashed_files);
     crate::reporter::pretty_print_duplicates(indexed_files, duplicates);
